#!/usr/bin/env bash
set -euo pipefail
IFS=$'\n'

# shellcheck source=src/bin/mosaic-common.bash
source "$(dirname "${BASH_SOURCE[0]}")/mosaic-common.bash"
set_usage "Mosaic Docker Wrapper" ""

MOSAIC_BASE_URI="617762925086.dkr.ecr.${REGION}.amazonaws.com"

function docker_login {
    echo "Logging in to Mosaic ECR repo at URI: $MOSAIC_BASE_URI"
    aws ecr get-login-password --region "$REGION" | docker login --username AWS --password-stdin "https://$MOSAIC_BASE_URI"
}

function docker_build {
    local directory="$1"
    
    if_verbose cd "${directory}"
    echo "Building Docker Image: ${APPLICATION}/${IMAGE_NAME}:${CI_COMMIT_SHORT_SHA}"
    docker build ./ -t "${APPLICATION}/${IMAGE_NAME}:${CI_COMMIT_SHORT_SHA}"
    docker tag "${APPLICATION}/${IMAGE_NAME}:${CI_COMMIT_SHORT_SHA}" "$MOSAIC_BASE_URI/mosaic/${PRODUCT}/${APPLICATION}/${IMAGE_NAME}:${CI_COMMIT_SHORT_SHA}"
}

function docker_push {
    echo "Pushing image to ECR Repo: ${MOSAIC_BASE_URI}/${PRODUCT}/${APPLICATION}"
    docker push "${MOSAIC_BASE_URI}/mosaic/${PRODUCT}/${APPLICATION}/${IMAGE_NAME}:${CI_COMMIT_SHORT_SHA}"
}

mosaic-configure.bash
parse_args "$@"

case "${action}" in
  build)
    docker_login
    docker_build  "${directory}"
    docker_push
    ;;
  *)
    usage
    ;;
esac