#!/usr/bin/env bash
set -euo pipefail
IFS=$'\n'

# shellcheck source=src/bin/mosaic-common.bash
source "$(dirname "${BASH_SOURCE[0]}")/mosaic-common.bash"
set_usage "Mosaic kubectl Wrapper" ""

function kubectl_check {
  local directory="$1"
  echo "==> DEPRECATED APIs <=="
  echo "See https://confluence.carbonblack.local/display/MOSAIC/Upcoming+Kubernetes+API+Removals for more details"
  if_verbose pluto --kubeconfig ~/.kube/config detect-files -d "$directory" -t k8s=v1.22.0 --ignore-deprecations --ignore-removals || true
  if_verbose kubectl apply --dry-run --recursive=true --filename="${directory}"
}

function kubectl_deploy {
  local directory="$1"
  if_verbose kubectl apply --recursive=true --wait=true --filename="${directory}"
}

function kubectl_destroy {
  local directory="$1"
  if_verbose kubectl delete --recursive=true --wait=true --filename="${directory}"
}

mosaic-configure.bash
unset_AWS_env_creds
parse_args "$@"

case "${action}" in
  check|show)
    kubectl_check "${directory}"
    ;;
  deploy)
    kubectl_deploy "${directory}"
    ;;
  destroy)
    kubectl_destroy "${directory}"
    ;;
  *)
    usage
    ;;
esac
